@@ -2,8 +2,8 @@
 
 #include "lcdclock.h"
 
-LcdClock::LcdClock(QColor &aColor, QString &aFormat, QWidget *parent)
-    : QLCDNumber(parent),  m_timeFormat(aFormat)
+LcdClock::LcdClock(QColor &aColor, QString &aFormat, int aBlink1, int aBlink2, QWidget *parent)
+    : QLCDNumber(parent),  m_timeFormat(aFormat), m_blink1(aBlink1), m_blink2(aBlink2)
 {
     setSegmentStyle(Filled);
     QSize aa = parent->size();
@@ -22,7 +22,15 @@ void LcdClock::showTime()
 {
     QTime time = QTime::currentTime();
     QString text = time.toString(m_timeFormat);
-//    if ((time.second() % 2) == 0)
-  //      text[2] = ' ';
+    if (m_blink1)
+    {
+        int lngt = text.length();
+        if ((time.second() % 2) == 0)
+        {
+            text[lngt-m_blink1] = ' ';
+            if (m_blink2)
+                text[lngt-m_blink2] = ' ';
+        }
+    }
     display(text);
 }
