@@ -21,6 +21,8 @@ public:
 
 protected:
     void mouseReleaseEvent ( QMouseEvent * e );
+    void mousePressEvent ( QMouseEvent * e );
+//    void mouseMoveEvent ( QMouseEvent * e );
 
 private slots:
     void showTime();
@@ -40,6 +42,10 @@ private:
     QSize m_size;
     int m_timer_tick;
     QString m_timeFormat;
+    bool m_mouseClick;
+    QPoint m_lastPoint;
+    int m_blinking1;
+    int m_blinking2;
 };
 
 #endif
