@@ -8,7 +8,7 @@ class FontClock : public QWidget
 {
     Q_OBJECT
 public:
-    explicit FontClock(QColor &aColor, QString &aFormat, QFont &aFont, QWidget *parent = 0);
+    explicit FontClock(QColor &aColor, QString &aFormat, QFont &aFont, int aBlink1, int aBlink2, QWidget *parent = 0);
 
 public slots:
     void showTime();
@@ -26,6 +26,8 @@ private:
     QFont m_font;
     QColor m_color;
     QString m_format;
+    int m_blink1;
+    int m_blink2;
 
 };
 
